.. _version_history:


Version History
===============

.. csv-table::
   :header: "Release", "Details"
   :widths: 20, 100

   "0.1.24", "adding new template tags"
   "0.1.5", "adding modal size parameter for modals used in create and filter forms"
   "0.1.0", "updates to support django 3.2"
   "0.0.27", "added HandyHelperListPlusFilterView and HandyHelperListPlusCreateAndFilterView"
   "0.0.26", "updated docstrings for views; added arg/kwargs to views"
   "0.0.25", "removing djangohelpers path; only using handyhelpers now"
   "0.0.24", "added zoom and card css"
   "0.0.23", "adding support for drf-dynamic-fields in INVALID_LOOKUP_SKIP_LIST"
   "0.0.22", "adding INVALID_LOOKUP_SKIP_LIST parameter via settings variable for InvalidLookupMixin"
   "0.0.21", "updating jinja templates and output path for drf generation"
   "0.0.20", "adding related_objects and distinct option to FilterByQueryParamsMixin"
